<?php
/*
Plugin Name: Bayan Blog Tools
Plugin URI: https://erfanahmadpour.ir
Description: ابزارهای بیان بلاگ
Version: 1.1
Author: Erfan Ahmadpour
Author URI: https://erfanahmadpour.ir
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class BayanBlogImporter {
    private $imported_count = 0;

    public function __construct() {
        add_action('admin_menu', array($this, 'create_menu'));
        add_action('admin_post_upload_bayan_xml', array($this, 'process_xml_upload'));
    }

    public function create_menu() {
        add_menu_page('بیان بلاگ', 'بیان بلاگ', 'manage_options', 'bayan-blog', array($this, 'wizard_page'));
    }

    public function wizard_page() {
        $step = isset($_GET['step']) ? intval($_GET['step']) : 1;
        echo '<div class="wrap"><h2>انتقال وبلاگ بیان</h2>';
        
        if ($step == 1) {
            echo '<h3>قوانین و مقررات</h3>';
            echo '<p>قبل از انتقال اطلاعات، لطفاً قوانین زیر را مطالعه و تأیید کنید.</p>';
            echo '<div style="border: 1px solid #ccc; padding: 10px; background: #f9f9f9;">   سلام! دوست خوبم این افزونه رو دوست نداشتم هیچ وقت بنویسم ولی چاره چیه؟ به زودی آپدیت هایی میاد روی این افزونه و کارایی هاش بیشتر میشه فقط یک خواسته ازت دارم اگر در توانت نیست یا دوست نداری از من حمایت مادی کنی می تونی با گذاشتن یک کامنت زیر همین پستی که ازش افزونه رو دانلود کردی به من روحیه بدی! دمت گرم به نوشتن ادامه بده که حال وب فارسی خرابه!
			</div>';
            echo '<br><a href="?page=bayan-blog&step=2" class="button button-primary">تأیید و ادامه</a>';
        } elseif ($step == 2) {
            echo '<h3>آپلود فایل XML</h3>';
            echo '<form method="post" action="admin-post.php" enctype="multipart/form-data">';
            wp_nonce_field('bayan_import_action', 'bayan_nonce');
            echo '<input type="hidden" name="action" value="upload_bayan_xml">';
            echo '<input type="file" name="xml_file" required />';
            echo '<br><br><input type="submit" name="upload_xml" value="آپلود و پردازش" class="button button-primary" />';
            echo '</form>';
        } elseif ($step == 3) {
            echo '<h3>انتقال موفق!</h3>';
            echo '<p>فرآیند انتقال مطالب از وبلاگ بیان به وردپرس با موفقیت انجام شد.</p>';
            echo '<p><strong>تعداد نوشته‌های منتقل‌شده:</strong> ' . get_option('bayan_imported_count', 0) . '</p>';
            echo '<br><a href="edit.php" class="button button-primary">مشاهده نوشته‌ها</a>';
        }
        echo '</div>';
    }

    public function process_xml_upload() {
        if (!current_user_can('manage_options')) {
            wp_die('دسترسی غیرمجاز');
        }

        if (!isset($_POST['bayan_nonce']) || !wp_verify_nonce($_POST['bayan_nonce'], 'bayan_import_action')) {
            wp_die('درخواست غیرمجاز');
        }

        if (!isset($_FILES['xml_file'])) {
            wp_die('فایلی انتخاب نشده است');
        }

        $xml_file = $_FILES['xml_file']['tmp_name'];
        $xml_content = simplexml_load_file($xml_file);

        if (!$xml_content) {
            wp_die('خطا در پردازش فایل XML');
        }

        foreach ($xml_content->POSTS->POST as $post) {
            $post_title = (string)$post->TITLE;
            $post_content = (string)$post->CONTENT;
            $post_date = date('Y-m-d H:i:s', strtotime((string)$post->CREATED_DATE));
            
            // استخراج دسته‌بندی‌ها
            $categories = [];
            foreach ($post->CATEGORIES->CATEGORY as $category) {
                $cat_name = (string)$category->NAME;
                $term = term_exists($cat_name, 'category');
                if (!$term) {
                    $term = wp_create_category($cat_name);
                }
                $categories[] = is_array($term) ? $term['term_id'] : $term;
            }

            // استخراج برچسب‌ها
            $tags = [];
            foreach ($post->TAGS->TAG as $tag) {
                $tags[] = (string)$tag->NAME;
            }

            // جایگزینی تصاویر
            $post_content = $this->replace_media($post_content);

            $post_data = array(
                'post_title'    => $post_title,
                'post_content'  => $post_content,
                'post_status'   => 'publish',
                'post_category' => $categories,
                'tags_input'    => $tags,
                'post_date'     => $post_date
            );

            wp_insert_post($post_data);
            $this->imported_count++;
        }

        update_option('bayan_imported_count', $this->imported_count);

        wp_redirect(admin_url('admin.php?page=bayan-blog&step=3'));
        exit;
    }

    private function replace_media($content) {
        preg_match_all('/https?:\/\/bayanbox\.ir\/[^\s"\']+/i', $content, $matches);
        require_once(ABSPATH . 'wp-admin/includes/media.php');
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        
        foreach ($matches[0] as $media_url) {
            // غیرفعال کردن بررسی SSL
            add_filter('https_ssl_verify', '__return_false');
            
            $tmp = download_url($media_url);
            
            if (is_wp_error($tmp)) {
                error_log('خطا در دانلود تصویر: ' . $media_url . ' - ' . $tmp->get_error_message());
                @unlink($tmp);
                continue;
            }
            
            $file_array = array(
                'name' => basename($media_url),
                'tmp_name' => $tmp
            );
            
            $attachment_id = media_handle_sideload($file_array, 0);
            
            if (is_wp_error($attachment_id)) {
                error_log('خطا در آپلود رسانه: ' . $attachment_id->get_error_message());
                @unlink($tmp);
                continue;
            }
            
            $new_url = wp_get_attachment_url($attachment_id);
            $content = preg_replace(
                '#' . preg_quote($media_url, '#') . '#',
                $new_url,
                $content
            );
        }
        return $content;
    }
}

new BayanBlogImporter();